@@ -784,17 +784,17 @@ class homework_four():
                 
                 print("Y_cs: {1} + {2} * Y_co + {3} * Y_cn\n-----------------------------\n")
                 for i in range(len(student_answer_Ycs)):
-                    if round(student_answer_Ycs[i],1) != sol_Ycs[i]:
+                    if round(student_answer_Ycs[i],1) != round(sol_Ycs[i],1):
                         counter += 1
                         print('Variable {} is WRONG\n'.format(i+1))
                 print("Y_cf: {1} + {2} * Y_co + {3} * Y_cn\n-----------------------------\n")
                 for i in range(len(student_answer_Ycf)):
-                    if round(student_answer_Ycf[i],1) != sol_Ycf[i]:
+                    if round(student_answer_Ycf[i],1) != round(sol_Ycf[i],1):
                         counter += 1
                         print('Variable {} is WRONG\n'.format(i+1))
                 print("Y_cp: {1} + {2} * Y_co + {3} * Y_cn\n-----------------------------\n")
                 for i in range(len(student_answer_Ycp)):
-                    if round(student_answer_Ycp[i],1) != sol_Ycp[i]:
+                    if round(student_answer_Ycp[i],1) != round(sol_Ycp[i],1):
                         counter += 1
                         print('Variable {} is WRONG\n'.format(i+1))
                 if counter != 0:
@@ -868,7 +868,7 @@ class homework_four():
                 Ycc = round(self.newCPR/self.newCPR,2) #(mol/h / mol/h)
                 Yco = round(self.newOCR/self.newCPR,2) #(mol/h / mol/h)
                 rn = self.newNSR/14 #(Secretion rate NH3 in gN/h / 14 g/mol)
-                Ycn = round(rn/self.newCPR,4) #(mol/h / mol/h)
+                Ycn = round(rn/self.newCPR,2) #(mol/h / mol/h)
                 
                 print('Yco: \n',Yco)
                 print('Ycn: \n',Ycn)
@@ -926,7 +926,7 @@ class homework_four():
                 Ycc = round(self.newCPR/self.newCPR,2) #(mol/h / mol/h)
                 Yco = round(self.newOCR/self.newCPR,2) #(mol/h / mol/h)
                 rn = self.newNSR/14 #(Secretion rate NH3 in gN/h / 14 g/mol)
-                Ycn = round(rn/self.newCPR,4) #(mol/h / mol/h)
+                Ycn = round(rn/self.newCPR,2) #(mol/h / mol/h)
                 
                 #Check first Checkpoint
                 counter = 0
